@@ -5,8 +5,7 @@ use strict;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = '1.26';
-
+$VERSION = '1.28';
 @ISA = qw(Set::Scalar::Real Set::Scalar::Null Set::Scalar::Base);
 
 use Set::Scalar::Base qw(_make_elements is_equal as_string_callback);
@@ -280,7 +279,7 @@ The Cartesian product of the above is the set
 
   ([a, c] [a, d] [a, e] [b, c] [b, d] [b, e])
 
-The [,] notation is for the ordered pairs, which sets are are not.
+The [,] notation is for the ordered pairs, which sets are not.
 This means two things: firstly, that [e, b] is B<not> in the above
 Cartesian product, and secondly, [b, b] is a possibility:
 
@@ -334,7 +333,7 @@ Even the empty set has a power set, of size one.
 If you don't want to construct the power set, you can construct an
 iterator and call it until it returns no more members:
 
-   my $iter = Set::Scalar->power_set($a);
+   my $iter = Set::Scalar->power_set_iterator($a);
    my @m;
    do {
      @m = $iter->();
@@ -396,6 +395,8 @@ intervals, and many more.  CPAN is your friend.
 =head1 AUTHOR
 
 Jarkko Hietaniemi <jhi@iki.fi>
+David Oswald <davido@cpan.org> is the current maintainer.
+The GitHub repo is at L<https://github.com/daoswald/Set-Scalar>
 
 =head1 COPYRIGHT AND LICENSE
 
