@@ -3,8 +3,9 @@ package Set::Scalar::Null;
 use strict;
 local $^W = 1;
 
-use vars qw(@ISA);
+use vars qw($VERSION @ISA);
 
+$VERSION = '1.28';
 @ISA = qw(Set::Scalar::Base Set::Scalar::Virtual);
 use Set::Scalar::Virtual;
 use Set::Scalar::Base;
