@@ -3,14 +3,13 @@ package Set::Scalar::Virtual;
 use strict;
 local $^W = 1;
 
-use vars qw(@ISA);
+use vars qw($VERSION @ISA);
 
+$VERSION = '1.28';
 @ISA = qw(Set::Scalar::Base);
 
 use Set::Scalar::Base qw(_make_elements as_string _compare _strval);
 
-use UNIVERSAL 'isa';
-
 use overload
     '""'	=> \&as_string,
     'eq'	=> \&are_equal,
@@ -69,7 +68,7 @@ B<Internal use only>.
 =head1 DESCRIPTION
 
 B<This is not the module you are looking for.>
-If you want documentation see L<Set::Scalar>.
+See the L<Set::Scalar>.
 
 =head1 AUTHOR
 
